@@ -1,7 +1,7 @@
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 from ytmusicapi.continuations import *
-from ytmusicapi.helpers import sum_total_duration, to_int
+from ytmusicapi.helpers import sum_total_duration
 from ytmusicapi.navigation import *
 from ytmusicapi.parsers.browsing import parse_content_list, parse_playlist
 from ytmusicapi.parsers.playlists import *
@@ -12,7 +12,7 @@ from ._utils import *
 
 class PlaylistsMixin(MixinProtocol):
     def get_playlist(
-        self, playlistId: str, limit: int = 100, related: bool = False, suggestions_limit: int = 0
+        self, playlistId: str, limit: Optional[int] = 100, related: bool = False, suggestions_limit: int = 0
     ) -> Dict:
         """
         Returns a list of playlist items
@@ -106,46 +106,16 @@ class PlaylistsMixin(MixinProtocol):
         body = {"browseId": browseId}
         endpoint = "browse"
         response = self._send_request(endpoint, body)
-        results = nav(response, SINGLE_COLUMN_TAB + SECTION_LIST_ITEM + ["musicPlaylistShelfRenderer"])
-        playlist = {"id": results["playlistId"]}
-        own_playlist = "musicEditablePlaylistDetailHeaderRenderer" in response["header"]
-        if not own_playlist:
-            header = response["header"]["musicDetailHeaderRenderer"]
-            playlist["privacy"] = "PUBLIC"
-        else:
-            header = response["header"]["musicEditablePlaylistDetailHeaderRenderer"]
-            playlist["privacy"] = header["editHeader"]["musicPlaylistEditHeaderRenderer"]["privacy"]
-            header = header["header"]["musicDetailHeaderRenderer"]
-        playlist["owned"] = own_playlist
-
-        playlist["title"] = nav(header, TITLE_TEXT)
-        playlist["thumbnails"] = nav(header, THUMBNAIL_CROPPED)
-        playlist["description"] = nav(header, DESCRIPTION, True)
-        run_count = len(nav(header, SUBTITLE_RUNS))
-        if run_count > 1:
-            playlist["author"] = {
-                "name": nav(header, SUBTITLE2),
-                "id": nav(header, [*SUBTITLE_RUNS, 2, *NAVIGATION_BROWSE_ID], True),
-            }
-            if run_count == 5:
-                playlist["year"] = nav(header, SUBTITLE3)
-
-        playlist["views"] = None
-        playlist["duration"] = None
-        if "runs" in header["secondSubtitle"]:
-            second_subtitle_runs = header["secondSubtitle"]["runs"]
-            has_views = (len(second_subtitle_runs) > 3) * 2
-            playlist["views"] = None if not has_views else to_int(second_subtitle_runs[0]["text"])
-            has_duration = (len(second_subtitle_runs) > 1) * 2
-            playlist["duration"] = (
-                None if not has_duration else second_subtitle_runs[has_views + has_duration]["text"]
+        results = nav(response, SINGLE_COLUMN_TAB + SECTION_LIST_ITEM + ["musicPlaylistShelfRenderer"], True)
+        if not results:
+            return self._parse_new_playlist_format(
+                response, endpoint, body, suggestions_limit, related, limit
             )
-            song_count = second_subtitle_runs[has_views + 0]["text"].split(" ")
-            song_count = to_int(song_count[0]) if len(song_count) > 1 else 0
-        else:
-            song_count = len(results["contents"])
 
-        playlist["trackCount"] = song_count
+        playlist = {"id": results["playlistId"]}
+        playlist.update(parse_playlist_header(response))
+        if playlist["trackCount"] is None:
+            playlist["trackCount"] = len(results["contents"])
 
         request_func = lambda additionalParams: self._send_request(endpoint, body, additionalParams)
 
@@ -154,7 +124,7 @@ class PlaylistsMixin(MixinProtocol):
         playlist["related"] = []
         if "continuations" in section_list:
             additionalParams = get_continuation_params(section_list)
-            if own_playlist and (suggestions_limit > 0 or related):
+            if playlist["owned"] and (suggestions_limit > 0 or related):
                 parse_func = lambda results: parse_playlist_items(results)
                 suggested = request_func(additionalParams)
                 continuation = nav(suggested, SECTION_LIST_CONTINUATION)
@@ -198,6 +168,107 @@ class PlaylistsMixin(MixinProtocol):
         playlist["duration_seconds"] = sum_total_duration(playlist)
         return playlist
 
+    def _parse_new_playlist_format(
+        self, response: Dict, endpoint, body, suggestions_limit, related, limit
+    ) -> Dict:  # pragma: no cover
+        """temporary function to avoid too many ifs in get_playlist during a/b test"""
+
+        header_data = nav(response, [*TWO_COLUMN_RENDERER, *TAB_CONTENT, *SECTION_LIST_ITEM])
+        section_list = nav(response, [*TWO_COLUMN_RENDERER, "secondaryContents", *SECTION])
+        playlist: Dict = {}
+        playlist["owned"] = EDITABLE_PLAYLIST_DETAIL_HEADER[0] in header_data
+        if not playlist["owned"]:
+            header = nav(header_data, RESPONSIVE_HEADER)
+            playlist["id"] = nav(
+                header,
+                ["buttons", 1, "musicPlayButtonRenderer", "playNavigationEndpoint", *WATCH_PLAYLIST_ID],
+                True,
+            )
+            playlist["privacy"] = "PUBLIC"
+        else:
+            playlist["id"] = nav(header_data, [*EDITABLE_PLAYLIST_DETAIL_HEADER, *PLAYLIST_ID])
+            header = nav(header_data, [*EDITABLE_PLAYLIST_DETAIL_HEADER, *HEADER, *RESPONSIVE_HEADER])
+            playlist["privacy"] = header_data[EDITABLE_PLAYLIST_DETAIL_HEADER[0]]["editHeader"][
+                "musicPlaylistEditHeaderRenderer"
+            ]["privacy"]
+
+        description_shelf = nav(header, ["description", *DESCRIPTION_SHELF], True)
+        playlist["description"] = (
+            "".join([run["text"] for run in description_shelf["description"]["runs"]])
+            if description_shelf
+            else None
+        )
+        playlist["title"] = nav(header, TITLE_TEXT)
+        playlist.update(parse_song_runs(nav(header, SUBTITLE_RUNS)[2 + playlist["owned"] * 2 :]))
+
+        playlist["views"] = None
+        playlist["duration"] = None
+        if "runs" in header["secondSubtitle"]:
+            second_subtitle_runs = header["secondSubtitle"]["runs"]
+            has_views = (len(second_subtitle_runs) > 3) * 2
+            playlist["views"] = None if not has_views else to_int(second_subtitle_runs[0]["text"])
+            has_duration = (len(second_subtitle_runs) > 1) * 2
+            playlist["duration"] = (
+                None if not has_duration else second_subtitle_runs[has_views + has_duration]["text"]
+            )
+            song_count = second_subtitle_runs[has_views + 0]["text"].split(" ")
+            song_count = to_int(song_count[0]) if len(song_count) > 1 else 0
+        else:
+            song_count = len(section_list["contents"])
+
+        playlist["trackCount"] = song_count
+
+        request_func = lambda additionalParams: self._send_request(endpoint, body, additionalParams)
+
+        # suggestions and related are missing e.g. on liked songs
+        playlist["related"] = []
+        if "continuations" in section_list:
+            additionalParams = get_continuation_params(section_list)
+            if playlist["owned"] and (suggestions_limit > 0 or related):
+                parse_func = lambda results: parse_playlist_items(results)
+                suggested = request_func(additionalParams)
+                continuation = nav(suggested, SECTION_LIST_CONTINUATION)
+                additionalParams = get_continuation_params(continuation)
+                suggestions_shelf = nav(continuation, CONTENT + MUSIC_SHELF)
+                playlist["suggestions"] = get_continuation_contents(suggestions_shelf, parse_func)
+
+                parse_func = lambda results: parse_playlist_items(results)
+                playlist["suggestions"].extend(
+                    get_continuations(
+                        suggestions_shelf,
+                        "musicShelfContinuation",
+                        suggestions_limit - len(playlist["suggestions"]),
+                        request_func,
+                        parse_func,
+                        reloadable=True,
+                    )
+                )
+
+            if related:
+                response = request_func(additionalParams)
+                continuation = nav(response, SECTION_LIST_CONTINUATION, True)
+                if continuation:
+                    parse_func = lambda results: parse_content_list(results, parse_playlist)
+                    playlist["related"] = get_continuation_contents(
+                        nav(continuation, CONTENT + CAROUSEL), parse_func
+                    )
+
+        playlist["tracks"] = []
+        content_data = nav(section_list, [*CONTENT, "musicPlaylistShelfRenderer"])
+        if "contents" in content_data:
+            playlist["tracks"] = parse_playlist_items(content_data["contents"])
+
+            parse_func = lambda contents: parse_playlist_items(contents)
+            if "continuations" in content_data:
+                playlist["tracks"].extend(
+                    get_continuations(
+                        content_data, "musicPlaylistShelfContinuation", limit, request_func, parse_func
+                    )
+                )
+
+        playlist["duration_seconds"] = sum_total_duration(playlist)
+        return playlist
+
     def get_liked_songs(self, limit: int = 100) -> Dict:
         """
         Gets playlist items for the 'Liked Songs' playlist
